@@ -8,17 +8,15 @@ Serves crap. Fast.
 """
 
 import os
-import sys
 
 import static
 
 PORT = os.environ.get('PORT', 8000)
-STATIC_DIR =  os.path.abspath(sys.argv[1])
+STATIC_DIR = os.environ.get('STATIC_DIR', '.')
 
 
 app = static.Cling(STATIC_DIR)
 
-
 def cli():
     print 'Serving crap. Fast.'
 
